@@ -9,10 +9,13 @@ if __name__ == "__main__":
     parser.add_argument("-l", "--ladder", action=BooleanOptionalAction, default=False)
     args = parser.parse_args()
     fp = find_swap_path if args.ladder else find_doublet_path
-    path = fp(args.start, args.end)
-    line = 1
-    for word in path:
-        if args.discord and line != 1 and word != args.end.upper():
-            word = "||" + word + "||"
-        print(f"{line}. {word}")
-        line += 1
+    try:
+        path = fp(args.start, args.end)
+        line = 1
+        for word in path:
+            if args.discord and line != 1 and word != args.end.upper():
+                word = "||" + word + "||"
+            print(f"{line}. {word}")
+            line += 1
+    except:
+        print(f"Could not create doublet from {args.start} to {args.end}")
